@@ -1,6 +1,6 @@
 #  MIT License
 #
-#  Copyright (c) 2017-2020 TileDB Inc.
+#  Copyright (c) 2017-2021 TileDB Inc.
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -39,16 +39,13 @@
 #'
 #' @export
 tiledb_array_create <- function(uri, schema, encryption_key) {
-  if (missing(uri) || !is.scalar(uri, "character")) {
-    stop("argument uri must be a string scalar")
-  } else if (missing(schema) || !is(schema, "tiledb_array_schema")) {
-    stop("argument schema must a tiledb_array_schema")
-  }
-  if (missing(encryption_key)) {
-    return(libtiledb_array_create(uri, schema@ptr))
-  } else {
-    return(libtiledb_array_create_with_key(uri, schema@ptr, encryption_key))
-  }
+    stopifnot(`The 'uri' argument must be a string scalar` = !missing(uri) && is.scalar(uri, "character"),
+              `The 'schema' argument must a tiledb_array_schema object` = !missing(schema) && is(schema, "tiledb_array_schema"))
+    if (missing(encryption_key)) {
+        return(libtiledb_array_create(uri, schema@ptr))
+    } else {
+        return(libtiledb_array_create_with_key(uri, schema@ptr, encryption_key))
+    }
 }
 
 ##' Open a TileDB Array
@@ -59,6 +56,7 @@ tiledb_array_create <- function(uri, schema, encryption_key) {
 ##' @importFrom methods .hasSlot
 ##' @export
 tiledb_array_open <- function(arr, type=c("READ","WRITE")) {
+  stopifnot(`The 'arr' argument must be a tiledb_array object` = is(arr, "tiledb_array") || is(arr, "tiledb_sparse") || is(arr, "tiledb_dense"))
   type <- match.arg(type)
 
   if (.hasSlot(arr, "encryption_key") && length(arr@encryption_key) > 0) {
@@ -78,7 +76,8 @@ tiledb_array_open <- function(arr, type=c("READ","WRITE")) {
 ##' @return The TileDB Array object but opened for reading or writing
 ##' @export
 tiledb_array_open_at <- function(arr, type=c("READ","WRITE"), timestamp) {
-  stopifnot(timestamp_argument=inherits(timestamp, "POSIXct"))
+  stopifnot(`The 'arr' argument must be a tiledb_array object` = is(arr, "tiledb_array") || is(arr, "tiledb_sparse") || is(arr, "tiledb_dense"),
+            `The 'timestamp' argument must a time object` = inherits(timestamp, "POSIXct"))
   type <- match.arg(type)
   ctx <- tiledb_get_context()
   if (.hasSlot(arr, "encryption_key") && length(arr@encryption_key) > 0) {
@@ -96,6 +95,7 @@ tiledb_array_open_at <- function(arr, type=c("READ","WRITE"), timestamp) {
 ##' @return The TileDB Array object but closed
 ##' @export
 tiledb_array_close <- function(arr) {
+  stopifnot(`The 'arr' argument must be a tiledb_array object` = is(arr, "tiledb_array") || is(arr, "tiledb_sparse") || is(arr, "tiledb_dense"))
   libtiledb_array_close(arr@ptr)
   arr
 }
@@ -106,6 +106,7 @@ tiledb_array_close <- function(arr) {
 ##' @return A boolean indicating if the array has homogeneous domains
 ##' @export
 tiledb_array_is_homogeneous <- function(arr) {
+  stopifnot(`The argument 'arr' must be a tiledb_array object` = is(arr, "tiledb_array") || is(arr, "tiledb_sparse") || is(arr, "tiledb_dense"))
   ## there is a non-exported call at the C level we could use instead
   sch <- schema(arr)
   dom <- domain(sch)
@@ -121,6 +122,7 @@ tiledb_array_is_homogeneous <- function(arr) {
 ##' @return A boolean indicating if the array has heterogenous domains
 ##' @export
 tiledb_array_is_heterogeneous <- function(arr) {
+  stopifnot(`The 'arr' argument must be a tiledb_array object` = is(arr, "tiledb_array") || is(arr, "tiledb_sparse") || is(arr, "tiledb_dense"))
   ## there is a non-exported call at the C level we could use instead
   sch <- schema(arr)
   dom <- domain(sch)
