@@ -7,8 +7,6 @@ isMacOS <- (Sys.info()['sysname'] == "Darwin")
 
 ctx <- tiledb_ctx(limitTileDBCores())
 
-if (tiledb_version(TRUE) < "2.0.0") exit_file("TileDB Array types required TileDB 2.0.* or greater")
-
 hasDataTable <- requireNamespace("data.table", quietly=TRUE)
 hasTibble <- requireNamespace("tibble", quietly=TRUE)
 
@@ -1237,96 +1235,6 @@ expect_error(array_vacuum(uri, end_time="def"))   # not a datetime
 expect_equal(array_vacuum(uri, start_time=now-60, end_time=now), NULL)
 
 
-## timestamp_start and timestamp_end
-uri <- tempfile()
-
-data <- data.frame(grp = rep(1:4, each=10), 				# 4 distinct groups
-                   val = rep(1:4, each=10) * 100 + 1:10)    # and 4 sets of value (used as index)
-
-fromDataFrame(subset(data, grp==1),     # write array, but only write group one
-              uri, sparse=TRUE,
-              col_index="val", tile_domain=list(val=range(data$val)))
-
-arr <- tiledb_array(uri)
-times <- Sys.time() + 0:3               # pre-allocate for four time stampps
-
-twot <- 1 + isMacOS*5
-onet <- twot/2
-Sys.sleep(twot)
-
-for (i in 2:4) {                        # in loop, write groups two to four
-    Sys.sleep(twot)
-    arr[] <- subset(data, grp==i)
-    times[i] <- Sys.time()              # and note time
-}
-
-arr <- tiledb_array(uri, as.data.frame=TRUE) 			# no limits
-expect_equal(NROW(arr[]), 40)                           # all four observations
-
-arr2 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_end=times[1])    # end before 1st timestamp
-expect_equal(NROW(arr2[]), 10)          # expect group one (10 elements)
-
-arr3 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[4]+onet) # start after fourth
-expect_equal(NROW(arr3[]), 0)           # expect zero data
-
-arr4 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_end=times[3]-onet)    # end before 3rd
-res4 <- arr4[]
-expect_equal(NROW(res4), 20)            # expect 2 groups, 20 obs
-expect_equal(max(res4$grp), 2)          # with groups being 1 and 2
-
-arr5 <- tiledb_array(uri, as.data.frame=TRUE, timestamp_start=times[2]-onet, timestamp_end=times[3])
-res5 <- arr5[]
-expect_equal(NROW(res5), 20)            # expects 2 groups, 2 and 3, with 20 obs
-expect_equal(min(res5$grp), 2)
-expect_equal(max(res5$grp), 3)
-
-## time-travel vaccum test
-vfs <- tiledb_vfs()
-ndirfull <- tiledb_vfs_ls(uri, vfs=vfs)
-array_consolidate(uri, start_time=times[2]-0.5, end_time=times[3])
-array_vacuum(uri, start_time=times[2]-0.5, end_time=times[3])
-ndircons <- tiledb_vfs_ls(uri, vfs=vfs)
-expect_true(length(ndircons) < length(ndirfull))
-array_consolidate(uri, start_time=times[1]-0.5, end_time=times[3])
-array_vacuum(uri, start_time=times[1]-0.5, end_time=times[3])
-ndircons2 <- tiledb_vfs_ls(uri, vfs=vfs)
-expect_true(length(ndircons2) < length(ndircons))
-
-## earlier time travel test recast via timestamp_{start,end}
-## time travel
-tmp <- tempfile()
-dir.create(tmp)
-dom <- tiledb_domain(dims = c(tiledb_dim("rows", c(1L, 10L), 5L, "INT32"),
-                              tiledb_dim("cols", c(1L, 10L), 5L, "INT32")))
-schema <- tiledb_array_schema(dom, attrs=c(tiledb_attr("a", type = "INT32")), sparse = TRUE)
-invisible( tiledb_array_create(tmp, schema) )
-
-I <- c(1, 2, 2)
-J <- c(1, 4, 3)
-data <- c(1L, 2L, 3L)
-now1 <- Sys.time()
-A <- tiledb_array(uri = tmp, timestamp_start=now1)
-A[I, J] <- data
-
-twot <- 1 + isMacOS*5
-onet <- twot/2
-Sys.sleep(twot)
-
-now2 <- Sys.time()
-I <- c(8, 6, 9)
-J <- c(5, 7, 8)
-data <- c(11L, 22L, 33L)
-A <- tiledb_array(uri = tmp, timestamp_start=now2)
-A[I, J] <- data
-
-A <- tiledb_array(uri = tmp, as.data.frame=TRUE, timestamp_end=now1 - onet)
-expect_equal(nrow(A[]), 0)
-A <- tiledb_array(uri = tmp, as.data.frame=TRUE, timestamp_start=now1 + onet)
-expect_equal(nrow(A[]), 3)
-A <- tiledb_array(uri = tmp, as.data.frame=TRUE, timestamp_end=now2 - onet)
-expect_equal(nrow(A[]), 3)
-A <- tiledb_array(uri = tmp, as.data.frame=TRUE, timestamp_end=now2 + onet)
-expect_equal(nrow(A[]), 6)
 
 
 ## test return preference
